@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Installation/include/CGAL/version.h $
-// $Id: version.h 454ac73 2023-07-26T14:15:18+02:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Installation/include/CGAL/version.h $
+// $Id: version.h dd3b569 2023-07-28T17:57:58+02:00 Laurent Rineau
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : -
@@ -17,12 +17,12 @@
 #define CGAL_VERSION_H
 
 #ifndef SWIG
-#define CGAL_VERSION 5.6
-#define CGAL_GIT_HASH de4fa0d7d57b5a997012f2804161386ff4bc0d0f
+#define CGAL_VERSION 5.6.1
+#define CGAL_GIT_HASH 188e51bad36ffc30e49dbabda29620b71a84664c
 #endif
-#define CGAL_VERSION_NR 1050601000
+#define CGAL_VERSION_NR 1050611000
 #define CGAL_SVN_REVISION 99999
-#define CGAL_RELEASE_DATE 20230726
+#define CGAL_RELEASE_DATE 20240224
 
 #include <CGAL/version_macros.h>
 
